==> jc-1.4.0.tar.gz: java/io/OutputStream.h <==
// public abstract class java.io.OutputStream

// class file dependencies
// @dep_class 4026d3144d6654d8 java_io_OutputStream
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_io_OutputStream_H_
#define _JC_java_io_OutputStream_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_io_OutputStream$sub_refs	_jc_java_io_OutputStream$sub_refs;
typedef struct _jc_java_io_OutputStream$sub_nonrefs	_jc_java_io_OutputStream$sub_nonrefs;
typedef struct _jc_java_io_OutputStream$refs	_jc_java_io_OutputStream$refs;
typedef struct _jc_java_io_OutputStream$nonrefs	_jc_java_io_OutputStream$nonrefs;
typedef struct _jc_java_io_OutputStream$object	_jc_java_io_OutputStream$object;

typedef const struct _jc_java_io_OutputStream$vmethods	_jc_java_io_OutputStream$vmethods;
typedef const struct _jc_java_io_OutputStream$vtable	_jc_java_io_OutputStream$vtable;
typedef const struct _jc_java_io_OutputStream$vtype	_jc_java_io_OutputStream$vtype;

// Constructors
extern void _jc_java_io_OutputStream$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_io_OutputStream$object *);

// Virtual methods
extern void _jc_java_io_OutputStream$method$close$6aba8b329fddcd79(_jc_env *, struct _jc_java_io_OutputStream$object *);
extern void _jc_java_io_OutputStream$method$flush$9dedb7d85e88cf56(_jc_env *, struct _jc_java_io_OutputStream$object *);
extern void _jc_java_io_OutputStream$method$write$6377ac6964854eb2(_jc_env *, struct _jc_java_io_OutputStream$object *, jint);
extern void _jc_java_io_OutputStream$method$write$18e189e8fc25f121(_jc_env *, struct _jc_java_io_OutputStream$object *, struct _jc_byte_array *);
extern void _jc_java_io_OutputStream$method$write$306a698343ec27e8(_jc_env *, struct _jc_java_io_OutputStream$object *, struct _jc_byte_array *, jint, jint);

// Virtual method descriptors
extern _jc_method _jc_java_io_OutputStream$method_info$close$6aba8b329fddcd79;
extern _jc_method _jc_java_io_OutputStream$method_info$flush$9dedb7d85e88cf56;
extern _jc_method _jc_java_io_OutputStream$method_info$write$6377ac6964854eb2;
extern _jc_method _jc_java_io_OutputStream$method_info$write$18e189e8fc25f121;
extern _jc_method _jc_java_io_OutputStream$method_info$write$306a698343ec27e8;

// Virtual methods structure
struct _jc_java_io_OutputStream$vmethods {
	void	(*close$6aba8b329fddcd79)(_jc_env *, struct _jc_java_io_OutputStream$object *);
	void	(*flush$9dedb7d85e88cf56)(_jc_env *, struct _jc_java_io_OutputStream$object *);
	void	(*write$6377ac6964854eb2)(_jc_env *, struct _jc_java_io_OutputStream$object *, jint);
	void	(*write$18e189e8fc25f121)(_jc_env *, struct _jc_java_io_OutputStream$object *, struct _jc_byte_array *);
	void	(*write$306a698343ec27e8)(_jc_env *, struct _jc_java_io_OutputStream$object *, struct _jc_byte_array *, jint, jint);
};

// Vtable
struct _jc_java_io_OutputStream$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_io_OutputStream$vmethods	java_io_OutputStream;
};

// Vtype
struct _jc_java_io_OutputStream$vtype {
	_jc_type			type;
	_jc_java_io_OutputStream$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_io_OutputStream$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_io_OutputStream$refs {
    _jc_java_io_OutputStream$sub_refs	java_io_OutputStream;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_io_OutputStream$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_io_OutputStream$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_io_OutputStream$sub_nonrefs	java_io_OutputStream;
};

// Object instance structure
struct _jc_java_io_OutputStream$object {
	_jc_java_io_OutputStream$refs	refs[0];
	_jc_word		lockword;
	_jc_java_io_OutputStream$vtype	*vtype;
	_jc_java_io_OutputStream$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_io_OutputStream$vtype _jc_java_io_OutputStream$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_io_OutputStream, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_io_OutputStream$class_object;

#endif	/* _JC_java_io_OutputStream_H_ */

==> jc-1.4.6.tar.gz: java/io/OutputStream.h <==
// public abstract class java.io.OutputStream

// class file dependencies
// @dep_class 4026d3144d6654d8 java_io_OutputStream
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_io_OutputStream_H_
#define _JC_java_io_OutputStream_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_io_OutputStream$sub_refs	_jc_java_io_OutputStream$sub_refs;
typedef struct _jc_java_io_OutputStream$sub_nonrefs	_jc_java_io_OutputStream$sub_nonrefs;
typedef struct _jc_java_io_OutputStream$refs	_jc_java_io_OutputStream$refs;
typedef struct _jc_java_io_OutputStream$nonrefs	_jc_java_io_OutputStream$nonrefs;
typedef struct _jc_java_io_OutputStream$object	_jc_java_io_OutputStream$object;

typedef const struct _jc_java_io_OutputStream$vmethods	_jc_java_io_OutputStream$vmethods;
typedef const struct _jc_java_io_OutputStream$vtable	_jc_java_io_OutputStream$vtable;
typedef const struct _jc_java_io_OutputStream$vtype	_jc_java_io_OutputStream$vtype;

// Constructors
extern void _jc_java_io_OutputStream$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_io_OutputStream$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_java_io_OutputStream$method$close$6aba8b329fddcd79(_jc_env *, struct _jc_java_io_OutputStream$object *) _JC_JCNI_ATTR;
extern void _jc_java_io_OutputStream$method$flush$9dedb7d85e88cf56(_jc_env *, struct _jc_java_io_OutputStream$object *) _JC_JCNI_ATTR;
extern void _jc_java_io_OutputStream$method$write$6377ac6964854eb2(_jc_env *, struct _jc_java_io_OutputStream$object *, jint) _JC_JCNI_ATTR;
extern void _jc_java_io_OutputStream$method$write$18e189e8fc25f121(_jc_env *, struct _jc_java_io_OutputStream$object *, struct _jc_byte_array *) _JC_JCNI_ATTR;
extern void _jc_java_io_OutputStream$method$write$306a698343ec27e8(_jc_env *, struct _jc_java_io_OutputStream$object *, struct _jc_byte_array *, jint, jint) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_io_OutputStream$method_info$close$6aba8b329fddcd79;
extern _jc_method _jc_java_io_OutputStream$method_info$flush$9dedb7d85e88cf56;
extern _jc_method _jc_java_io_OutputStream$method_info$write$6377ac6964854eb2;
extern _jc_method _jc_java_io_OutputStream$method_info$write$18e189e8fc25f121;
extern _jc_method _jc_java_io_OutputStream$method_info$write$306a698343ec27e8;

// Virtual methods structure
struct _jc_java_io_OutputStream$vmethods {
	void	(*close$6aba8b329fddcd79)(_jc_env *, struct _jc_java_io_OutputStream$object *) _JC_JCNI_ATTR;
	void	(*flush$9dedb7d85e88cf56)(_jc_env *, struct _jc_java_io_OutputStream$object *) _JC_JCNI_ATTR;
	void	(*write$6377ac6964854eb2)(_jc_env *, struct _jc_java_io_OutputStream$object *, jint) _JC_JCNI_ATTR;
	void	(*write$18e189e8fc25f121)(_jc_env *, struct _jc_java_io_OutputStream$object *, struct _jc_byte_array *) _JC_JCNI_ATTR;
	void	(*write$306a698343ec27e8)(_jc_env *, struct _jc_java_io_OutputStream$object *, struct _jc_byte_array *, jint, jint) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_io_OutputStream$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_io_OutputStream$vmethods	java_io_OutputStream;
};

// Vtype
struct _jc_java_io_OutputStream$vtype {
	_jc_type			type;
	_jc_java_io_OutputStream$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_io_OutputStream$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_io_OutputStream$refs {
    _jc_java_io_OutputStream$sub_refs	java_io_OutputStream;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_io_OutputStream$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_io_OutputStream$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_io_OutputStream$sub_nonrefs	java_io_OutputStream;
};

// Object instance structure
struct _jc_java_io_OutputStream$object {
	_jc_java_io_OutputStream$refs	refs[0];
	_jc_word		lockword;
	_jc_java_io_OutputStream$vtype	*vtype;
	_jc_java_io_OutputStream$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_io_OutputStream$vtype _jc_java_io_OutputStream$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_io_OutputStream, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_io_OutputStream$class_object;

#endif	/* _JC_java_io_OutputStream_H_ */
